@@ -292,6 +292,47 @@ typedef struct {
 SIGAR_DECLARE(int) sigar_proc_mem_get(sigar_t *sigar, sigar_pid_t pid,
                                       sigar_proc_mem_t *procmem);
 
+typedef struct {
+     sigar_uint64_t 
+        bytes_read,
+        bytes_written,
+        bytes_total;
+} sigar_proc_disk_io_t;
+
+SIGAR_DECLARE(int) sigar_proc_disk_io_get(sigar_t *sigar, sigar_pid_t pid,
+                                          sigar_proc_disk_io_t *proc_disk_io);
+
+typedef struct {
+    sigar_uint64_t
+        bytes_read,
+        bytes_written,
+        bytes_total;
+    sigar_uint64_t last_time;
+    sigar_uint64_t
+        bytes_read_diff,
+        bytes_written_diff,
+        bytes_total_diff;
+} sigar_cached_proc_disk_io_t;
+
+
+typedef struct {
+    sigar_uint64_t
+        bytes_read,
+        bytes_written,
+        bytes_total;
+} sigar_proc_cumulative_disk_io_t;
+
+SIGAR_DECLARE(int) sigar_proc_cumulative_disk_io_get(sigar_t *sigar, sigar_pid_t pid,
+                                          sigar_proc_cumulative_disk_io_t *proc_cumulative_disk_io);
+
+
+typedef struct  { 
+    sigar_uint64_t dummy;
+}sigar_dump_pid_cache_t;
+
+SIGAR_DECLARE(int) sigar_dump_pid_cache_get(sigar_t *sigar, sigar_dump_pid_cache_t *info);
+
+
 typedef struct {
     sigar_uid_t uid;
     sigar_gid_t gid;
