@@ -754,6 +754,23 @@ int sigar_proc_mem_get(sigar_t *sigar, sigar_pid_t pid,
     return SIGAR_OK;
 }
 
+int sigar_proc_cumulative_disk_io_get(sigar_t *sigar, sigar_pid_t pid,
+                           sigar_proc_cumulative_disk_io_t *cumulative_proc_disk_io)
+{
+    int status = sigar_getprocs(sigar, pid);
+    struct procsinfo64 *pinfo = sigar->pinfo;
+
+    if (status != SIGAR_OK) {
+        return status;
+    }
+    cumulative_proc_disk_io->bytes_read = SIGAR_FIELD_NOTIMPL;
+    cumulative_proc_disk_io->bytes_written =  SIGAR_FIELD_NOTIMPL;
+    cumulative_proc_disk_io->bytes_total = pinfo->pi_ioch;
+
+    return SIGAR_OK;
+}
+
+
 int sigar_proc_cred_get(sigar_t *sigar, sigar_pid_t pid,
                         sigar_proc_cred_t *proccred)
 {
