@@ -345,6 +345,8 @@ typedef struct {
     sigar_uint64_t handles;
     sigar_uint64_t threads;
     sigar_uint64_t page_faults;
+	sigar_uint64_t bytes_read;
+	sigar_uint64_t bytes_written;
 } sigar_win32_pinfo_t;
 
 typedef struct {
