@@ -1338,6 +1338,14 @@ static ptql_lookup_t PTQL_Cpu[] = {
     { NULL }
 };
 
+static ptql_lookup_t PTQL_Disk_IO[] = {
+    { "BytesRead", PTQL_LOOKUP_ENTRY(proc_disk_io, bytes_read, UI64) },
+    { "BytesWritten",      PTQL_LOOKUP_ENTRY(proc_disk_io, bytes_written, UI64) },
+    { "BytesTotal",       PTQL_LOOKUP_ENTRY(proc_disk_io, bytes_total, UI64) },
+    { NULL }
+};
+
+
 static ptql_lookup_t PTQL_CredName[] = {
     { "User",  PTQL_LOOKUP_ENTRY(proc_cred_name, user, STR) },
     { "Group", PTQL_LOOKUP_ENTRY(proc_cred_name, group, STR) },
@@ -1424,6 +1432,7 @@ static ptql_entry_t ptql_map[] = {
     { "Port",     PTQL_Port },
     { "Pid",      PTQL_Pid },
     { "Service",  PTQL_Service },
+    { "Disk_IO",   PTQL_Disk_IO },
     { NULL }
 };
 
